@@ -14,14 +14,8 @@ mainwindow::mainwindow(QWidget *parent) :
 
     ui->setupUi(this);
 
-    if (!QFile::exists("/opt/cssutransitionstuner/cssuinstalled")) {
-        ui->blurless->setDisabled(true);
-        ui->forcerotation->setDisabled(true);
-        ui->parallax->setDisabled(true);
-        ui->zaxis->setDisabled(true);
-        ui->tactile->setDisabled(true);
-        ui->taskswitcher->setDisabled(true);
-        ui->zoomonpress->setDisabled(true);
+    if (QFile::exists("/opt/cssutransitionstuner/cssuinstalled")) {
+        QMaemo5InformationBox::information(this, tr("Could not detect Community SSU being installed.<br /><br />You may still try to use the CSSU Tuner, but some functions may not have effect."), QMaemo5InformationBox::NoTimeout);
     }
 
     if (!QFile::exists("/opt/cssutransitionstuner/tactileinstalled")) {
@@ -34,7 +28,7 @@ mainwindow::mainwindow(QWidget *parent) :
     orientationChanged();
     readvalues();
     abouttext = tr("Author: d-iivil<br />Licence: GPL");
-    abouttitle = "CSSU Tuner " + tr("version") + " 0.1.7";
+    abouttitle = "CSSU Tuner " + tr("version") + " 0.1.8";
 }
 
 mainwindow::~mainwindow()
