@@ -4,8 +4,33 @@
 <context>
     <name>mainwindow</name>
     <message>
-        <source>CSSU Transitions tuner</source>
-        <translation>CSSU Transitions Tuner</translation>
+        <source>CSSU Tuner</source>
+        <translation>CSSU Tuner</translation>
+    </message>
+    <message>
+        <source>Transitions lenght (ms)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Status menu rows</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Status menu rows
+(portait)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Always show FM-applet</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>App menu editing Enabled</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Homescreen editing Enabled</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <source>Ultra fast Transitions</source>
